@@ -1,3 +1,3 @@
 from .abstract_webtools import get_url_mgr
 from .managers import *
-from .abstract_usurpit import usurpManager,test_download,usurpit
+from .abstract_usurpit import usurpManager,usurpit
